@@ -13,7 +13,10 @@
 # limitations under the License.
 
 """Provider-specific schema implementations."""
+from __future__ import annotations
 
-from langextract.providers.schemas.gemini import GeminiSchema
+from langextract.providers.schemas import gemini
+
+GeminiSchema = gemini.GeminiSchema  # Backward compat
 
 __all__ = ["GeminiSchema"]
